@@ -10,3 +10,5 @@ from pymonad.Reader import *
 from pymonad.Maybe import *
 from pymonad.Either import *
 from pymonad.List import *
+from pymonad.Monoid import *
+from pymonad.Writer import *
